{-# LANGUAGE OverloadedStrings #-}
module TurtleDisplay where

import qualified Data.Array as Ar
import Data.Char(toLower)
import Control.Monad (forM_)

import Text.Blaze.Html5 as H
import Text.Blaze.Html5.Attributes as A
import Text.Blaze.Html.Renderer.String (renderHtml)

import Turtle as T

displayTo :: String-> T -> IO ()
displayTo fnm = writeFile fnm . renderHtml . turtlepage

turtlepage :: T-> Html
turtlepage t = 
  docTypeHtml $ do
    H.head $ do
      H.title "Turtle Graphics"
      H.style stylesheet 
    body $ do
      h1 "Turtle Graphics"
      grid t
    
grid :: T -> Html
grid t = table ! A.id "pixels"  $ (forM_ (reverse [0.. y-1]) $ td . line ) where
  (x, y)= T.size t
  line :: Int-> Html
  line j  = tr $ forM_ [0.. x-1] (\i-> td "" ! class_ (cls i j))
  cls :: Int-> Int-> AttributeValue
  cls i j = case colourAt t (i,j) of
              Black -> "pixel black"
              Red-> "pixel red"
              Blue-> "pixel blue"
              Yellow-> "pixel yellow"
              Green-> "pixel green"
              White-> "pixel white"

stylesheet =
 " body { background-colour: #cccccc; } \
 \ #pixels { border-collapse: collapse; background-color: black; } \
 \ td.pixel { width: 10px; height: 10px; } \
 \ td.black { background-color: black; } \
 \ td.red { background-color: red; } \
 \ td.blue { background-color: blue; } \
 \ td.yellow { background-color: yellow; } \
 \ td.green { background-color: green; } \
 \ td.white{ background-color: white; } "
